@@ -1,14 +1,14 @@
 package Gtk2::Atk::Object;
 
-# $Id: Object.pm,v 1.1 2002/11/11 19:56:59 gthyni Exp $
+# $Id: Object.pm,v 1.2 2002/12/16 17:24:05 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Object.pm,v 1.1 2002/11/11 19:56:59 gthyni Exp $';
+our $rcsid = '$Id: Object.pm,v 1.2 2002/12/16 17:24:05 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::GObject;
 @ISA=qw(Gtk2::GObject);
