@@ -1,14 +1,14 @@
 package Gtk2::Layout;
 
-# $Id: Layout.pm,v 1.2 2002/11/09 16:23:15 gthyni Exp $
+# $Id: Layout.pm,v 1.4 2002/12/16 17:20:39 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Layout.pm,v 1.2 2002/11/09 16:23:15 gthyni Exp $';
+our $rcsid = '$Id: Layout.pm,v 1.4 2002/12/16 17:20:39 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::Container;
 @ISA = qw(Gtk2::Container);
@@ -32,7 +32,7 @@ sub thaw {
 }
 
 sub get_size {
-    my $s = shift->_get_size();
+    my $s = shift->_get_size;
     return wantarray ? @$s : $s;
 }
 
