@@ -1,13 +1,13 @@
 package Gtk2::Pango::Context;
 
-# $Id: Context.pm,v 1.4 2002/11/14 21:31:56 gthyni Exp $
+# $Id: Context.pm,v 1.5 2002/12/16 17:24:35 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: Context.pm,v 1.4 2002/11/14 21:31:56 gthyni Exp $';
+our $rcsid = '$Id: Context.pm,v 1.5 2002/12/16 17:24:35 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-BEGIN { do 'Gtk2/_config.pm'; }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 1;
