@@ -1,11 +1,11 @@
 package Gtk2::TextBuffer;
 
-# $Id: TextBuffer.pm,v 1.11 2002/12/16 17:22:40 ggc Exp $
+# $Id: TextBuffer.pm,v 1.12 2003/03/04 12:25:39 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: TextBuffer.pm,v 1.11 2002/12/16 17:22:40 ggc Exp $';
+our $rcsid = '$Id: TextBuffer.pm,v 1.12 2003/03/04 12:25:39 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
 BEGIN { do 'Gtk2/_config.pm'; $@ and die }
@@ -21,5 +21,10 @@ sub get_bounds {
     return wantarray ? @$b : $b;
 }
 
+sub get_selection_bounds {
+    my $b = shift->_get_selection_bounds;
+    return wantarray ? @$b : $b;
+}
+
 1;
 
