@@ -1,14 +1,14 @@
 package Gtk2::TextMark;
 
-# $Id: TextMark.pm,v 1.3 2002/12/16 17:22:47 ggc Exp $
+# $Id: TextMark.pm,v 1.4 2003/03/04 12:25:39 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: TextMark.pm,v 1.3 2002/12/16 17:22:47 ggc Exp $';
+our $rcsid = '$Id: TextMark.pm,v 1.4 2003/03/04 12:25:39 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
+BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use base qw(Gtk2::GObject);
 
