@@ -1,14 +1,14 @@
 package Gtk2::TreeDataList;
 
-# $Id: TreeDataList.pm,v 1.1 2002/11/11 19:50:29 gthyni Exp $
+# $Id: TreeDataList.pm,v 1.2 2002/12/16 17:23:06 ggc Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
 
-our $rcsid = '$Id: TreeDataList.pm,v 1.1 2002/11/11 19:50:29 gthyni Exp $';
+our $rcsid = '$Id: TreeDataList.pm,v 1.2 2002/12/16 17:23:06 ggc Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
-#BEGIN { do 'Gtk2/_config.pm'; }
+#BEGIN { do 'Gtk2/_config.pm'; $@ and die }
 
 use Gtk2::_Object;
 @ISA=qw(Gtk2::_Object);
