@@ -1,6 +1,6 @@
 package Gtk2::_Object;
 
-# $Id: _Object.pm,v 1.12 2003/02/09 20:23:05 gthyni Exp $
+# $Id: _Object.pm,v 1.13 2003/03/04 13:29:02 joered Exp $
 # Copyright 2002, Gran Thyni, kirra.net
 # licensed with Lesser General Public License (LGPL)
 # see http://www.fsf.org/licenses/lgpl.txt
@@ -8,7 +8,7 @@ package Gtk2::_Object;
 # This is internal class which should be parent to
 # all classes in Gtk2, gobjects or not.
 
-our $rcsid = '$Id: _Object.pm,v 1.12 2003/02/09 20:23:05 gthyni Exp $';
+our $rcsid = '$Id: _Object.pm,v 1.13 2003/03/04 13:29:02 joered Exp $';
 our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;
 
 use strict;
@@ -46,13 +46,21 @@ sub AUTOLOAD
     eval "use $class";
     die $@ if $@;
     my $func = (split /::/, $AUTOLOAD)[-1];
-    my $rc = eval { $class->$func(@_) };
+
+    my (@rc, $rc);
+    if ( wantarray ) {
+	@rc = eval { $class->$func(@_) };
+    } else {
+	$rc = eval { $class->$func(@_) };
+    }
+
     if ( $@ ) {
 	my $exc = $@;
 	$exc =~ s/\s+at\s+.*?line\s+\d+\.\n$//;
 	croak $exc;
     }
-    return $rc;
+    
+    return wantarray ? @rc : $rc;
   }
 
 1;
