@@ -248,16 +248,20 @@
 #define SvGtkRequisition_nullok(o) (SvROK(o) ? ((GtkRequisition*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkRequisition")))) : NULL)
 #define SvGtkBoxChild(o) ((GtkBoxChild*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkBoxChild"))))
 #define SvGtkBoxChild_nullok(o) (SvROK(o) ? ((GtkBoxChild*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkBoxChild")))) : NULL)
+#define SvGtkIconSet(o) ((GtkIconSet*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkIconSet"))))
+#define SvGtkIconSet_nullok(o) (SvROK(o) ? ((GtkIconSet*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkIconSet")))) : NULL)
+#define SvGtkIconSource(o) ((GtkIconSource*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkIconSource"))))
+#define SvGtkIconSource_nullok(o) (SvROK(o) ? ((GtkIconSource*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkIconSource")))) : NULL)
+#define SvGtkSelectionData(o) ((GtkSelectionData*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkSelectionData"))))
+#define SvGtkSelectionData_nullok(o) (SvROK(o) ? ((GtkSelectionData*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkSelectionData")))) : NULL)
+#define SvGtkTextIter(o) ((GtkTextIter*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTextIter"))))
+#define SvGtkTextIter_nullok(o) (SvROK(o) ? ((GtkTextIter*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTextIter")))) : NULL)
 #define SvGtkTreeIter(o) ((GtkTreeIter*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTreeIter"))))
 #define SvGtkTreeIter_nullok(o) (SvROK(o) ? ((GtkTreeIter*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTreeIter")))) : NULL)
 #define SvGtkTreeModel(o) ((GtkTreeModel*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTreeModel"))))
 #define SvGtkTreeModel_nullok(o) (SvROK(o) ? ((GtkTreeModel*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTreeModel")))) : NULL)
 #define SvGtkTreePath(o) ((GtkTreePath*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTreePath"))))
 #define SvGtkTreePath_nullok(o) (SvROK(o) ? ((GtkTreePath*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTreePath")))) : NULL)
-#define SvGtkTextIter(o) ((GtkTextIter*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTextIter"))))
-#define SvGtkTextIter_nullok(o) (SvROK(o) ? ((GtkTextIter*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkTextIter")))) : NULL)
-#define SvGtkSelectionData(o) ((GtkSelectionData*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkSelectionData"))))
-#define SvGtkSelectionData_nullok(o) (SvROK(o) ? ((GtkSelectionData*) SvIV(SvRV(gtk2_perl_check_type(o, "GtkSelectionData")))) : NULL)
 #define SvGtkAccelFlags(o) gtk2_perl_convert_flags(GTK_TYPE_ACCEL_FLAGS, o)
 #define newSVGtkAccelFlags(o) gtk2_perl_convert_back_flags(GTK_TYPE_ACCEL_FLAGS, o)
 #define SvGtkCalendarDisplayOptions(o) gtk2_perl_convert_flags(GTK_TYPE_CALENDAR_DISPLAY_OPTIONS, o)
