@@ -1,4 +1,4 @@
-/* $Id: AspectFrame.c,v 1.5 2002/10/30 20:30:33 borup Exp $
+/* $Id: AspectFrame.c,v 1.6 2003/01/16 21:24:03 joered Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -9,7 +9,7 @@
 
 #include "gtk2-perl.h"
 
-SV* gtkperl_aspect_frame_new(char* class, gchar* label, double xalign, double yalign, double ratio, int obey_child)
+SV* gtkperl_aspect_frame__new(char* class, gchar* label, double xalign, double yalign, double ratio, int obey_child)
 {
     return gtk2_perl_new_object(gtk_aspect_frame_new(label, xalign, yalign, ratio, obey_child));
 }
