@@ -1,4 +1,4 @@
-/* $Id: OptionMenu.c,v 1.7 2002/10/23 09:13:56 gthyni Exp $
+/* $Id: OptionMenu.c,v 1.8 2003/01/17 18:46:01 dlacroix Exp $
  * Copyright 2002, Gran Thyni, kirra.net
  * licensed with Lesser General Public License (LGPL)
  * see http://www.fsf.org/licenses/lgpl.txt
@@ -24,3 +24,13 @@ void gtkperl_option_menu_set_menu(SV* option_menu, SV* menu)
     gtk_option_menu_set_menu(SvGtkOptionMenu(option_menu), SvGtkWidget(menu));
 }
 
+void gtkperl_option_menu_set_history(SV *option_menu, int index)
+{
+    gtk_option_menu_set_history(SvGtkOptionMenu(option_menu), index);
+}
+
+int gtkperl_option_menu_get_history(SV *option_menu)
+{
+    return gtk_option_menu_get_history(SvGtkOptionMenu(option_menu));
+}
+
